"use client";
import { useState, useEffect, useRef } from "react";
import { usePathname } from "next/navigation";
import Link from "next/link";
import styles from "./header.module.scss";
import { Logo, LogoIcon } from "@/components/general/Logo";

export const Header = () => {
  const [showMenu, setShowMenu] = useState(false);
  function toggleMenu() {
    setShowMenu(!showMenu);
  }
  const siteMenu = useRef<HTMLInputElement>(null);
  useEffect(() => {
    // only add the event listener when the siteMenu is opened
    if (!showMenu) return;
    function handleClick(event: Event) {
      if (
        siteMenu.current &&
        !siteMenu.current.contains(event.target as Node)
      ) {
        setShowMenu(false);
        setActiveMenuItem(undefined);
      }
    }
    window.addEventListener("click", handleClick);
    // clean up
    return () => window.removeEventListener("click", handleClick);
  }, [showMenu]);

  useEffect(() => {
    if (showMenu) {
      document.body.style.overflow = "hidden";
      document.body.style.height = "100vh";
    } else {
      document.body.style.overflow = "";
      document.body.style.height = "";
    }
  }, [showMenu]);

  const pathname = usePathname();
  useEffect(() => {
    // hide menu on path change
    setShowMenu(false);
    setActiveMenuItem(undefined);
  }, [pathname]);

  const [activeMenuItem, setActiveMenuItem] = useState<string | undefined>(
    undefined
  );

  return (
    <header className={styles.header}>
      <Link href="/" aria-label="Hjem">
        <Logo />
      </Link>
      <nav className={styles.siteMenu} data-show={showMenu} ref={siteMenu}>
        <ul className={styles.mainMenu}>
          <li>
            <Link
              href="/arrangementer"
              data-active={pathname === "/arrangementer"}
            >
              Arrangementer
            </Link>
          </li>
          <li>
            <Link href="/praktisk" data-active={pathname === "/praktisk"}>
              Praktisk info
            </Link>
          </li>
          <li>
            <Link href="/utleie" data-active={pathname === "/utleie"}>
              Utleie
            </Link>
          </li>
          <li>
            <Link href="/" data-active={pathname === "/medlem"}>
              Bli medlem
            </Link>
          </li>
        </ul>
        <button
          className={styles.toggleMenu}
          aria-label="Vis meny"
          onClick={toggleMenu}
        >
          <span className={styles.menuIcon}></span>
        </button>
        <div className={styles.fullMenu}>
          <LogoIcon face="right" />
          <ul>
            <li className={styles.menuItemLarge}>
              <Link
                href="/arrangementer"
                data-active={pathname === "/arrangementer"}
              >
                Arrangementer
              </Link>
            </li>
            <li className={styles.menuItemLarge}>
              <Link href="/praktisk" data-active={pathname === "/praktisk"}>
                Praktisk info
              </Link>
            </li>
            <li className={styles.menuItemLarge}>
              <Link href="/utleie" data-active={pathname === "/utleie"}>
                Utleie
              </Link>
            </li>
            <li className={styles.menuItemLarge}>
              <Link href="/" data-active={pathname === "/medlem"}>
                Bli medlem
              </Link>
            </li>
            <li className={styles.divider}>
              <Link href="/aktuelt" data-active={pathname === "/aktuelt"}>
                Siste nytt
              </Link>
            </li>
            <li>
              <Link href="/" data-active={pathname === "/om"}>
                Om oss
              </Link>
            </li>
            <li>
              <Link href="/kontakt" data-active={pathname === "/kontakt"}>
                Kontakt
              </Link>
            </li>
            <li>
              <Link href="/" data-active={pathname === "/frivillig"}>
                Bli frivillig
              </Link>
            </li>
            <li className={styles.search}>
              <label>
                <p>Søk</p>
                <input type="text" />
              </label>
            </li>
            <li className={styles.galtinn}>
              <Link href="/">Mitt medlemskap &rarr;</Link>
            </li>
            <li>
              {/* TODO: skal trolig ikke være så synlig ved lansering */}
              <Link href="/lokaler">Lokaler*</Link>
            </li>
          </ul>
        </div>
      </nav>
    </header>
  );
};
