/* eslint-disable */
import * as types from './graphql';
import { TypedDocumentNode as DocumentNode } from '@graphql-typed-document-node/core';

/**
 * Map of all GraphQL operations in the project.
 *
 * This map has several performance disadvantages:
 * 1. It is not tree-shakeable, so it will include all operations in the project.
 * 2. It is not minifiable, so the string of a GraphQL query will be multiple times inside the bundle.
 * 3. It does not support dead code elimination, so it will add unused operations.
 *
 * Therefore it is highly recommended to use the babel or swc plugin for production.
 */
const documents = {
    "\n  fragment Generic on GenericPage {\n    __typename\n    id\n    urlPath\n    title\n    body {\n      ...Blocks\n    }\n  }\n": types.GenericFragmentDoc,
    "\n    query allGenericSlugs {\n      pages(contentType: \"generic.GenericPage\") {\n        id\n        urlPath\n      }\n    }\n  ": types.AllGenericSlugsDocument,
    "\n    query genericPageByUrl($urlPath: String!) {\n      page: page(contentType: \"generic.GenericPage\", urlPath: $urlPath) {\n        ... on GenericPage {\n          ...Generic\n        }\n      }\n    }\n  ": types.GenericPageByUrlDocument,
    "\n    query allEventSlugs {\n      pages(contentType: \"events.EventPage\") {\n        id\n        slug\n      }\n    }\n  ": types.AllEventSlugsDocument,
    "\n    query eventBySlug($slug: String!) {\n      event: page(contentType: \"events.EventPage\", slug: $slug) {\n        ... on EventPage {\n          ...Event\n        }\n      }\n    }\n  ": types.EventBySlugDocument,
    "\n    query allAssociationSlugs {\n      pages(contentType: \"associations.AssociationPage\") {\n        id\n        slug\n      }\n    }\n  ": types.AllAssociationSlugsDocument,
    "\n    query associationBySlug($slug: String!) {\n      association: page(\n        contentType: \"associations.AssociationPage\"\n        slug: $slug\n      ) {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  ": types.AssociationBySlugDocument,
    "\n  fragment AssociationIndex on AssociationIndex {\n    ... on AssociationIndex {\n      title\n      lead\n      body {\n        id\n        blockType\n        field\n        ... on RichTextBlock {\n          rawValue\n          value\n        }\n      }\n    }\n  }\n": types.AssociationIndexFragmentDoc,
    "\n  fragment Association on AssociationPage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    logo {\n      url\n      width\n      height\n    }\n    associationType\n    websiteUrl\n  }\n": types.AssociationFragmentDoc,
    "\n    query allAssociations {\n      index: page(\n        contentType: \"associations.AssociationIndex\"\n        urlPath: \"/home/foreninger/\"\n      ) {\n        ... on AssociationIndex {\n          ...AssociationIndex\n        }\n      }\n      associations: pages(contentType: \"associations.AssociationPage\") {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  ": types.AllAssociationsDocument,
    "\n    query allVenueSlugs {\n      pages(contentType: \"venues.VenuePage\") {\n        id\n        slug\n      }\n    }\n  ": types.AllVenueSlugsDocument,
    "\n    query venueBySlug($slug: String!) {\n      venue: page(contentType: \"venues.VenuePage\", slug: $slug) {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  ": types.VenueBySlugDocument,
    "\n  fragment Venue on VenuePage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    featuredImage {\n      ...Image\n    }\n    showAsBookable\n    floor\n    preposition\n    capabilityAudio\n    capabilityAudioVideo\n    capabilityBar\n    capabilityLighting\n    capacityLegal\n    capacityStanding\n    capacitySitting\n  }\n": types.VenueFragmentDoc,
    "\n    query allVenues {\n      venues: pages(contentType: \"venues.VenuePage\") {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  ": types.AllVenuesDocument,
    "\n  fragment Home on HomePage {\n    ... on HomePage {\n      featuredEvents {\n        id\n      }\n    }\n  }\n": types.HomeFragmentDoc,
    "\n    query home {\n      events: pages(contentType: \"events.EventPage\") {\n        ...Event\n      }\n      home: page(contentType: \"home.HomePage\", urlPath: \"/home/\") {\n        ... on HomePage {\n          ...Home\n        }\n      }\n    }\n  ": types.HomeDocument,
    "\n  fragment Blocks on StreamFieldInterface {\n    id\n    blockType\n    field\n    ... on RichTextBlock {\n      rawValue\n      value\n    }\n    ... on ImageWithTextBlock {\n      image {\n        ...Image\n      }\n      imageFormat\n      text\n    }\n    ... on ImageSliderBlock {\n      images {\n        ... on ImageSliderItemBlock {\n          image {\n            ...Image\n          }\n          text\n        }\n      }\n    }\n  }\n": types.BlocksFragmentDoc,
    "\n  fragment Image on CustomImage {\n    id\n    url\n    width\n    height\n    alt\n    attribution\n  }\n": types.ImageFragmentDoc,
    "\n  fragment Event on EventPage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    featuredImage {\n      ...Image\n    }\n    facebookUrl\n    ticketUrl\n    priceRegular\n    priceMember\n    priceStudent\n    categories {\n      ... on EventCategory {\n        name\n        slug\n      }\n    }\n    occurrences {\n      ... on EventOccurrence {\n        __typename\n        id\n        start\n        end\n        venue {\n          __typename\n          id\n          slug\n          title\n        }\n      }\n    }\n  }\n": types.EventFragmentDoc,
    "\n  query allEvents {\n    events: pages(contentType: \"events.EventPage\") {\n      ... on EventPage {\n        ...Event\n      }\n    }\n    eventCategories: eventCategories {\n      ... on EventCategory {\n        name\n        slug\n        showInFilters\n      }\n    }\n  }\n": types.AllEventsDocument,
};

/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 *
 *
 * @example
 * ```ts
 * const query = graphql(`query GetUser($id: ID!) { user(id: $id) { name } }`);
 * ```
 *
 * The query argument is unknown!
 * Please regenerate the types.
 */
export function graphql(source: string): unknown;

/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Generic on GenericPage {\n    __typename\n    id\n    urlPath\n    title\n    body {\n      ...Blocks\n    }\n  }\n"): (typeof documents)["\n  fragment Generic on GenericPage {\n    __typename\n    id\n    urlPath\n    title\n    body {\n      ...Blocks\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allGenericSlugs {\n      pages(contentType: \"generic.GenericPage\") {\n        id\n        urlPath\n      }\n    }\n  "): (typeof documents)["\n    query allGenericSlugs {\n      pages(contentType: \"generic.GenericPage\") {\n        id\n        urlPath\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query genericPageByUrl($urlPath: String!) {\n      page: page(contentType: \"generic.GenericPage\", urlPath: $urlPath) {\n        ... on GenericPage {\n          ...Generic\n        }\n      }\n    }\n  "): (typeof documents)["\n    query genericPageByUrl($urlPath: String!) {\n      page: page(contentType: \"generic.GenericPage\", urlPath: $urlPath) {\n        ... on GenericPage {\n          ...Generic\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allEventSlugs {\n      pages(contentType: \"events.EventPage\") {\n        id\n        slug\n      }\n    }\n  "): (typeof documents)["\n    query allEventSlugs {\n      pages(contentType: \"events.EventPage\") {\n        id\n        slug\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query eventBySlug($slug: String!) {\n      event: page(contentType: \"events.EventPage\", slug: $slug) {\n        ... on EventPage {\n          ...Event\n        }\n      }\n    }\n  "): (typeof documents)["\n    query eventBySlug($slug: String!) {\n      event: page(contentType: \"events.EventPage\", slug: $slug) {\n        ... on EventPage {\n          ...Event\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allAssociationSlugs {\n      pages(contentType: \"associations.AssociationPage\") {\n        id\n        slug\n      }\n    }\n  "): (typeof documents)["\n    query allAssociationSlugs {\n      pages(contentType: \"associations.AssociationPage\") {\n        id\n        slug\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query associationBySlug($slug: String!) {\n      association: page(\n        contentType: \"associations.AssociationPage\"\n        slug: $slug\n      ) {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  "): (typeof documents)["\n    query associationBySlug($slug: String!) {\n      association: page(\n        contentType: \"associations.AssociationPage\"\n        slug: $slug\n      ) {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment AssociationIndex on AssociationIndex {\n    ... on AssociationIndex {\n      title\n      lead\n      body {\n        id\n        blockType\n        field\n        ... on RichTextBlock {\n          rawValue\n          value\n        }\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment AssociationIndex on AssociationIndex {\n    ... on AssociationIndex {\n      title\n      lead\n      body {\n        id\n        blockType\n        field\n        ... on RichTextBlock {\n          rawValue\n          value\n        }\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Association on AssociationPage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    logo {\n      url\n      width\n      height\n    }\n    associationType\n    websiteUrl\n  }\n"): (typeof documents)["\n  fragment Association on AssociationPage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    logo {\n      url\n      width\n      height\n    }\n    associationType\n    websiteUrl\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allAssociations {\n      index: page(\n        contentType: \"associations.AssociationIndex\"\n        urlPath: \"/home/foreninger/\"\n      ) {\n        ... on AssociationIndex {\n          ...AssociationIndex\n        }\n      }\n      associations: pages(contentType: \"associations.AssociationPage\") {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  "): (typeof documents)["\n    query allAssociations {\n      index: page(\n        contentType: \"associations.AssociationIndex\"\n        urlPath: \"/home/foreninger/\"\n      ) {\n        ... on AssociationIndex {\n          ...AssociationIndex\n        }\n      }\n      associations: pages(contentType: \"associations.AssociationPage\") {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allVenueSlugs {\n      pages(contentType: \"venues.VenuePage\") {\n        id\n        slug\n      }\n    }\n  "): (typeof documents)["\n    query allVenueSlugs {\n      pages(contentType: \"venues.VenuePage\") {\n        id\n        slug\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query venueBySlug($slug: String!) {\n      venue: page(contentType: \"venues.VenuePage\", slug: $slug) {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  "): (typeof documents)["\n    query venueBySlug($slug: String!) {\n      venue: page(contentType: \"venues.VenuePage\", slug: $slug) {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Venue on VenuePage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    featuredImage {\n      ...Image\n    }\n    showAsBookable\n    floor\n    preposition\n    capabilityAudio\n    capabilityAudioVideo\n    capabilityBar\n    capabilityLighting\n    capacityLegal\n    capacityStanding\n    capacitySitting\n  }\n"): (typeof documents)["\n  fragment Venue on VenuePage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    featuredImage {\n      ...Image\n    }\n    showAsBookable\n    floor\n    preposition\n    capabilityAudio\n    capabilityAudioVideo\n    capabilityBar\n    capabilityLighting\n    capacityLegal\n    capacityStanding\n    capacitySitting\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allVenues {\n      venues: pages(contentType: \"venues.VenuePage\") {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  "): (typeof documents)["\n    query allVenues {\n      venues: pages(contentType: \"venues.VenuePage\") {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Home on HomePage {\n    ... on HomePage {\n      featuredEvents {\n        id\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment Home on HomePage {\n    ... on HomePage {\n      featuredEvents {\n        id\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query home {\n      events: pages(contentType: \"events.EventPage\") {\n        ...Event\n      }\n      home: page(contentType: \"home.HomePage\", urlPath: \"/home/\") {\n        ... on HomePage {\n          ...Home\n        }\n      }\n    }\n  "): (typeof documents)["\n    query home {\n      events: pages(contentType: \"events.EventPage\") {\n        ...Event\n      }\n      home: page(contentType: \"home.HomePage\", urlPath: \"/home/\") {\n        ... on HomePage {\n          ...Home\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Blocks on StreamFieldInterface {\n    id\n    blockType\n    field\n    ... on RichTextBlock {\n      rawValue\n      value\n    }\n    ... on ImageWithTextBlock {\n      image {\n        ...Image\n      }\n      imageFormat\n      text\n    }\n    ... on ImageSliderBlock {\n      images {\n        ... on ImageSliderItemBlock {\n          image {\n            ...Image\n          }\n          text\n        }\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment Blocks on StreamFieldInterface {\n    id\n    blockType\n    field\n    ... on RichTextBlock {\n      rawValue\n      value\n    }\n    ... on ImageWithTextBlock {\n      image {\n        ...Image\n      }\n      imageFormat\n      text\n    }\n    ... on ImageSliderBlock {\n      images {\n        ... on ImageSliderItemBlock {\n          image {\n            ...Image\n          }\n          text\n        }\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Image on CustomImage {\n    id\n    url\n    width\n    height\n    alt\n    attribution\n  }\n"): (typeof documents)["\n  fragment Image on CustomImage {\n    id\n    url\n    width\n    height\n    alt\n    attribution\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Event on EventPage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    featuredImage {\n      ...Image\n    }\n    facebookUrl\n    ticketUrl\n    priceRegular\n    priceMember\n    priceStudent\n    categories {\n      ... on EventCategory {\n        name\n        slug\n      }\n    }\n    occurrences {\n      ... on EventOccurrence {\n        __typename\n        id\n        start\n        end\n        venue {\n          __typename\n          id\n          slug\n          title\n        }\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment Event on EventPage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    featuredImage {\n      ...Image\n    }\n    facebookUrl\n    ticketUrl\n    priceRegular\n    priceMember\n    priceStudent\n    categories {\n      ... on EventCategory {\n        name\n        slug\n      }\n    }\n    occurrences {\n      ... on EventOccurrence {\n        __typename\n        id\n        start\n        end\n        venue {\n          __typename\n          id\n          slug\n          title\n        }\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  query allEvents {\n    events: pages(contentType: \"events.EventPage\") {\n      ... on EventPage {\n        ...Event\n      }\n    }\n    eventCategories: eventCategories {\n      ... on EventCategory {\n        name\n        slug\n        showInFilters\n      }\n    }\n  }\n"): (typeof documents)["\n  query allEvents {\n    events: pages(contentType: \"events.EventPage\") {\n      ... on EventPage {\n        ...Event\n      }\n    }\n    eventCategories: eventCategories {\n      ... on EventCategory {\n        name\n        slug\n        showInFilters\n      }\n    }\n  }\n"];

export function graphql(source: string) {
  return (documents as any)[source] ?? {};
}

export type DocumentType<TDocumentNode extends DocumentNode<any, any>> = TDocumentNode extends DocumentNode<  infer TType,  any>  ? TType  : never;